OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Fjalëkalim i gabuar",
    "The new password can not be the same as the previous one" : "Fjalëkalimi i ri s’mund të jetë i njëjtë me të mëparshmin",
    "No user supplied" : "S’u dha përdorues",
    "Authentication error" : "Gabim mirëfilltësimi",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Ju lutemi, jepni një fjalëkalim rikthimesh për përgjegjësin, në të kundërt të gjitha të dhënat do të humbasin.",
    "Wrong admin recovery password. Please check the password and try again." : "Fjalëkalim i gabuar rikthimesh për përgjegjësin. Ju lutemi, kontrolloni fjalëkalimin dhe provoni përsëri.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Programi klient s’mbulon ndryshime fjalëkalimi, por kyçi i përdoruesi për fshehtëzime u përditësua me sukses.",
    "Unable to change password" : "S’arrihet të ndryshohet fjalëkalimi",
    "%s password changed successfully" : "Fjalëkalimi për %s u ndryshua me sukses",
    "Couldn't send reset email. Please contact your administrator." : "S’u dërgua dot email-i i ricaktimit. Ju lutemi, lidhuni me përgjegjësin tuaj.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "instalim dhe përditësim aplikacionesh përmes shitores së aplikacioneve ose Federated Cloud Sharing",
    "Federated Cloud Sharing" : "Ndarje Në Re të Federuar ",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL-ja po përdor një version %s të vjetruar (%s). Ju lutemi, përditësoni sistemin tuaj operativ ose përndryshe veçori të tilla si %s nuk do të punojnë në mënyrë të qëndrueshme.",
    "A problem occurred, please check your log files (Error: %s)" : "Ndodhi një gabim, ju lutemi, kontrolloni kartelat tuaja regjistër (Error: %s)",
    "Migration Completed" : "Migrimi u Plotësua",
    "Group already exists." : "Grupi ekziston tashmë.",
    "Unable to add group." : "S’arrihet të shtohet grup.",
    "Unable to delete group." : "S’arrihet të fshihet grup.",
    "log-level out of allowed range" : "nivel regjistrimi jashtë intervalit të lejuar",
    "Saved" : "U ruajt",
    "test email settings" : "testoni rregullime email-i",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ndodhi një gabim gjatë dërgimit të email-it. Ju lutemi, rishikoni rregullimet tuaja. (Error: %s)",
    "Email sent" : "Email-i u dërgua",
    "You need to set your user email before being able to send test emails." : "Lypset të caktoni email-in tuaj si përdorues, përpara se të jeni në gjendje të dërgoni email-e provë.",
    "Couldn't change the email address because the user does not exist" : "S’u ndryshua dot adresa email, ngaqë përdoruesi s’ekziston",
    "Couldn't change the email address because the token is invalid" : "S’u ndryshua dot adresa email, ngaqë token-i është i pavlefshëm",
    "Invalid mail address" : "Adresë email e pavlefshme",
    "A user with that name already exists." : "Ka tashmë një përdorues me këtë emër.",
    "Unable to create user." : "S’arrihet të krijohet përdoruesi.",
    "Your %s account was created" : "Llogaria juaj %s u krijua",
    "Unable to delete user." : "S’arrihet të fshihet përdorues.",
    "Forbidden" : "E ndaluar",
    "Invalid user" : "Përdorues i pavlefshëm",
    "Unable to change mail address" : "S’arrihet të ndryshohet adresë email",
    "Email has been changed successfully." : "Email-i u ndryshua me sukses.",
    "An email has been sent to this address for confirmation" : "Te kjo adresë është dërguar një email për ripohim.",
    "No email was sent because you already sent one recently. Please try again later." : "S’u dërgua email, ngaqë keni dërguar një të tillë tani së fundi. Ju lutemi, riprovoni më vonë.",
    "Your full name has been changed." : "Emri juaj i plotë u ndryshua.",
    "Unable to change full name" : "S’arrihet të ndryshohet emri i plotë",
    "%s email address confirm" : "Ripohim adrese email %s",
    "Couldn't send email address change confirmation mail. Please contact your administrator." : "S’u dërgua dot email ripohimi ndryshimi adrese email. Ju lutemi, lidhuni me përgjegjësin tuaj.",
    "%s email address changed successfully" : "Adresa email %s u ndryshua me sukses",
    "Couldn't send email address change notification mail. Please contact your administrator." : "S’u dërgua dot email njoftimi ndryshimi adrese email. Ju lutemi, lidhuni me përgjegjësin tuaj.",
    "Unable to enable/disable user." : "S’arrihet të aktivizohet/çaktivizohet përdoruesi.",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "__language_name__" : "Shqip",
    "Language changed" : "Gjuha u ndryshua",
    "Invalid request" : "Kërkesë e pavlefshme",
    "Admins can't remove themself from the admin group" : "Administratorët s’mund të heqin veten prej grupit admin",
    "Unknown user" : "Përdorues i panjohur",
    "Couldn't remove app." : "S’u hoq dot aplikacioni.",
    "Official" : "Zyrtare",
    "Approved" : "Të miratuara",
    "All" : "Krejt",
    "Enabled" : "E aktivizuar",
    "Not enabled" : "E paaktivizuar",
    "No apps found for your version" : "S’u gjetën aplikacione për versionin tuaj",
    "The app will be downloaded from the app store" : "Aplikacioni do të shkarkohet nga shitorja e aplikacioneve",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Aplikacionet zyrtare ndërtohen brenda bashkësisë ownCloud. Ato ofrojnë funksione qendrore për ownCloud dhe janë gati për t’u përdorur në prodhim.",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Aplikacionet e miratuara ndërtohen nga zhvillues të besuar dhe kanë kaluar një kontroll të përciptë sigurie. Mirëmbahen aktivisht në një depo të hapur kodi dhe mirëmbajtësit e tyre i konsiderojnë të qëndrueshme për përdorime nga të rastit deri në ato normale.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Ky aplikacion s’është kontrolluar për probleme sigurie dhe është i ri ose i njohur si i paqëndrueshëm. Instalojeni duke e mbajtur vetë përgjegjësinë.",
    "Please wait...." : "Ju lutemi, prisni…",
    "Error while disabling app" : "Gabim në çaktivizimin e aplikacionit",
    "Disable" : "Çaktivizoje",
    "Enable" : "Aktivizoje",
    "Error while enabling app" : "Gabim në aktivizimin e aplikacionit",
    "Error: this app cannot be enabled because it makes the server unstable" : "Gabim: ky aplikacion s’u aktivizua dot, ngaqë e bën shërbyesin të paqëndrueshëm.",
    "Error: could not disable broken app" : "Gabim: s’u çaktivizua dot aplikacion i dëmtuar",
    "Error while disabling broken app" : "Gabim teksa çaktivizohej aplikacion i dëmtuar",
    "Updating...." : "Po përditësohet…",
    "Error while updating app" : "Gabim gjatë përditësimit të aplikacionit",
    "Updated" : "U përditësua",
    "Uninstalling ...." : "Po çinstalohet…",
    "Error while uninstalling app" : "Gabim në çinstalimin e aplikacionit",
    "Uninstall" : "Çinstaloje",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikacioni është aktivizuar, por lyp të përditësohet. Për 5 sekonda do të ridrejtoheni te faqja e përditësimeve.",
    "App update" : "Përditësim aplikacioni",
    "Experimental" : "Eksperimentale",
    "No apps found for {query}" : "S’u gjetën aplikacione për {query}",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Jeni vërtet i sigurt se doni të shtoni \"{domain}\" si përkatësi të besuar?",
    "Add trusted domain" : "Shtoni përkatësi të besuar",
    "Migration in progress. Please wait until the migration is finished" : "Migrimi në rrugë e sipër. Ju lutemi, pritni, teksa migrimi përfundon",
    "Migration started …" : "Migrimi filloi …",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Ndodhi një gabim. Ju lutemi, ngarkoni një dëshmi PEM të koduar me ASCII.",
    "Valid until {date}" : "E vlefshme deri më {date}",
    "Delete" : "Fshije",
    "Disconnect" : "Shkëputu",
    "Error while loading browser sessions and device tokens" : "Gabim gjatë ngarkimit të sesioneve të shfletuesit dhe token-ësh pajisjesh",
    "Error while creating device token" : "Gabim gjatë krijimit të token-ëve të pajisjejeve",
    "Error while deleting the token" : "Gabim gjatë fshirjes së token-it",
    "Sending..." : "Po dërgohet…",
    "Failed to change the email address." : "Dështoi ndryshimi i adresës email.",
    "Email changed successfully." : "Email-i u ndryshua me sukses.",
    "An error occurred: {message}" : "Ndodhi një gabim: {message}",
    "Select a profile picture" : "Përzgjidhni një foto profili",
    "Very weak password" : "Fjalëkalim shumë i dobët",
    "Weak password" : "Fjalëkalim i dobët",
    "So-so password" : "Fjalëkalim çka",
    "Good password" : "Fjalëkalim i mirë",
    "Strong password" : "Fjalëkalim i fortë",
    "Groups" : "Grupe",
    "Unable to delete {objName}" : "S’arrihet të fshihet {objName}",
    "Error creating group: {message}" : "Gabim gjatë krijimit të grupit: {message}",
    "A valid group name must be provided" : "Duhet dhënë një emër i vlefshëm grupi",
    "deleted {groupName}" : "u fshi {groupName}",
    "undo" : "zhbëje",
    "never" : "kurrë",
    "deleted {userName}" : "u fshi {userName}",
    "add group" : "shto grup",
    "Invalid quota value \"{val}\"" : "Vlerë kuotash e pavlefshme \"{val}\"",
    "enabled" : "e aktivizuar",
    "disabled" : "e çaktivizuar",
    "User {uid} has been {state}!" : "Përdoruesi {uid} është {state}!",
    "no group" : "pa grup",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Ndryshimi i fjalëkalimit do të sjellë humbje të dhënash, ngaqë rikthimi i të dhënave s’është i përdorshëm për këtë përdorues",
    "Password successfully changed" : "Fjalëkalimi u ndryshua me sukses",
    "A valid username must be provided" : "Duhet dhënë një emër të vlefshëm përdoruesi",
    "Error creating user: {message}" : "Gabim gjatë krijimit të përdoruesit: {message}",
    "A valid password must be provided" : "Duhet dhënë një fjalëkalim i vlefshëm",
    "A valid email must be provided" : "Duhet dhënë një email i vlefshëm",
    "Use the following link to confirm your changes to the email address: {link}" : "Që të ripohoni ndryshimet te adresa juaj email, përdorni lidhjen vijuese: {link}",
    "Email address changed to {mailAddress} successfully." : "Adresa email u ndryshua me sukses në {mailAddress}.",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Njatjeta,<br><br>thjesht po ju bëjmë të ditur që tani keni një llogari %s.<br><br>Emri juaj i përdoruesit: %s<br>Hyni në të te: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "Gëzuar!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Njatjeta,\n\nthjesht po ju bëjmë të ditur që tani keni një llogari %s.\n\nEmri juaj i përdoruesit: %s\nHyni në të te: %s\n\n",
    "User documentation" : "Dokumentim për përdorues",
    "Administrator documentation" : "Dokumentim për përgjegjës",
    "Online documentation" : "Dokumentim në Internet",
    "Forum" : "Forum",
    "Issue tracker" : "Gjurmues të metash",
    "Commercial support" : "Asistencë komerciale",
    "Apps Management" : "Administrim Aplikacionesh",
    "Developer documentation" : "Dokumentim për zhvillues",
    "by %s" : "nga %s",
    "%s-licensed" : "licencuar prej %s",
    "Documentation:" : "Dokumentim:",
    "Admin documentation" : "Dokumentim për përgjegjësit",
    "Visit website" : "Vizitoni sajtin",
    "Report a bug" : "Njoftoni një të metë",
    "Show description …" : "Shfaq përshkrim …",
    "Hide description …" : "Fshihe përshkrimin …",
    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Ky aplikacion nuk ka të përcaktuar version minimum për ownCloud-in. Kjo do të përbëjë një gabim për ownCloud 11 dhe të mëvonshëm.",
    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Ky aplikacion nuk ka të përcaktuar version maksimum për ownCloud-in. Kjo do të përbëjë një gabim për ownCloud 11 dhe të mëvonshëm.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ky aplikacion s’mund të instalohet, ngaqë për të nuk plotësohen varësitë vijuese:",
    "Enable only for specific groups" : "Aktivizoje vetëm për grupe të veçantë",
    "Uninstall App" : "Çinstaloje Aplikacionin",
    "Show enabled apps" : "Shfaq aplikacione të aktivizuara",
    "Show disabled apps" : "Shfaq aplikacione të çaktivizuara",
    "Cron" : "Cron",
    "Last cron job execution: %s." : "Përmbushja e fundit e aktit cron: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Përmbushja e fundit e aktit cron: %s. Duket se nuk shkon diçka.",
    "Cron was not executed yet!" : "Cron-i s’qe ekzekutuar ende!",
    "Open documentation" : "Hapni dokumentimin",
    "Execute one task with each page loaded" : "Kryeni vetëm një veprim me secilën prej faqeve të ngarkuara",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php është regjistruar te një shërbim webcron që ta aktivizojë cron.php-në çdo 15 minuta përmes http-je.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Përdorni shërbimin cron të sistemit që ta aktivizojë cron.php-në çdo 15 minuta.",
    "SSL Root Certificates" : "Dëshmi SSL Rrënjë",
    "Common Name" : "Emër i Rëndomtë",
    "Valid until" : "E vlefshme deri më",
    "Issued By" : "Lëshuar Nga",
    "Valid until %s" : "E vlefshme deri më %s",
    "Import root certificate" : "Importoni dëshmi rrënjë",
    "Server-side encryption" : "Fshehtëzim më anë shërbyesi",
    "Enable server-side encryption" : "Aktivizo fshehtëzim më anë të shërbyesit",
    "Please read carefully before activating server-side encryption: " : "Ju lutemi, lexoni me kujdes përpara aktivizimit të fshehtëzimeve më anë shërbyesi: ",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Pasi të jetë aktivizuar fshehtëzimi, krejt kartelat e ngarkuara te shërbyesi nga kjo pikë e tutje do të fshehtëzohen pasi të jenë depozituar në shërbyes. Çaktivizimi i fshehtëzimit në një datë të mëvonshme do të jetë i mundur vetëm nëse moduli aktiv i fshehtëzimeve e mbulon këtë funksion, dhe nëse plotësohen krejt parakushtet (p.sh. caktimi i një kyçi rimarrjesh).",
    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "Fshehtëzimi, dhe vetëm kaq, s’garanton sigurinë e sistemit. Ju lutemi, për më tepër të dhëna se si funksionon aplikacioni i fshehtëzimeve, dhe për raste përdorimi që mbulon, lexoni dokumentimin e ownCloud-it.",
    "Be aware that encryption always increases the file size." : "Kini parasysh që fshehtëzimi e rrit gjithnjë madhësinë e kartelës.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Është gjithmonë ide e mirë të krijohen kopjeruajtje të rregullta të të dhënave tuaja, në rast fshehtëzimi sigurohuni që bëni kopjeruajtje të kyçeve të fshehtëzimit, tok me të dhënat tuaja.",
    "This is the final warning: Do you really want to enable encryption?" : "Ky është sinjalizimi përfundimtar: Doni vërtet të aktivizohet fshehtëzimi?",
    "Enable encryption" : "Aktivizoni fshehtëzim",
    "No encryption module loaded, please enable an encryption module in the app menu." : "S’ka të ngarkuar modul fshehtëzimi, ju lutemi, aktivizoni një modul fshehtëzimi që nga menuja e aplikacionit.",
    "Select default encryption module:" : "Përzgjidhni modul parazgjedhje fshehtëzimi:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Lypset të migroni kyçet tuaj të fshehtëzimit nga fshehtëzimi i vjetër (ownCloud <= 8.0) te i riu. Ju lutemi, aktivizoni \"Modul parazgjedhje fshehtëzimesh\" dhe ekzekutoni 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Lypset të migroni kyçet tuaj të fshehtëzimit nga fshehtëzimi i vjetër (ownCloud <= 8.0) te i riu.",
    "Start migration" : "Fillo migrimin",
    "Sharing" : "Ndarje me të tjerët",
    "Allow apps to use the Share API" : "Lejoni aplikacionet të përdorin API Share",
    "Allow users to share via link" : "Lejoji përdoruesit të ndajnë me të tjerët përmes lidhjesh",
    "Allow public uploads" : "Lejo ngarkime publike",
    "Enforce password protection" : "Detyro mbrojtje me fjalëkalim",
    "Set default expiration date" : "Caktoni datë parazgjedhje skadimi",
    "Allow users to send mail notification for shared files" : "Lejoju përdoruesve të dërgojnë njoftime me email për kartela të ndara me të tjerët",
    "Allow users to share file via social media" : "Lejoji përdoruesit të ndajnë gjëra përmes mediash shoqërore",
    "Expire after " : "Skadon pas ",
    "days" : "ditësh",
    "Enforce expiration date" : "Detyro datë skadimi",
    "Allow resharing" : "Lejo rindarje",
    "Allow sharing with groups" : "Lejoni ndarje me grupe",
    "Restrict users to only share with users in their groups" : "Përdoruesve kufizoju të ndajnë gjëra vetëm me përdorues në grupin e tyre",
    "Allow users to send mail notification for shared files to other users" : "Lejoju përdoruesve t’u dërgojnë përdoruesve të tjerë njoftime me email për kartela të ndara me të tjerët",
    "Exclude groups from sharing" : "Përjashtoni grupe nga ndarjet",
    "These groups will still be able to receive shares, but not to initiate them." : "Këto grupe prapë do të jenë në gjendje të marrin ndarje nga të tjerët, por jo të fillojnë të tilla.",
    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Lejo vetëplotësim emra përdoruesish te dialogu i ndarjeve me të tjerët. Nëse kjo është e çaktivizuar, do të duhet të jepen emra përdoruesish.",
    "Restrict enumeration to group members" : "Kufizojeni numërtimin për anëtarë grupi",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Gjithçka (probleme fatale, gabime, sinjalizime, të dhëna, diagnostikim)",
    "Info, warnings, errors and fatal issues" : "Të dhëna, sinjalizime, gabime dhe probleme fatale",
    "Warnings, errors and fatal issues" : "Sinjalizime, gabime dhe probleme fatale",
    "Errors and fatal issues" : "Gabime dhe probleme fatale",
    "Fatal issues only" : "Vetëm probleme fatale",
    "Log" : "Regjistër",
    "What to log" : "Ç’të regjistrohet",
    "Download logfile (%s)" : "Shkarkoni kartelën regjistër (%s)",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Kartela regjistër është më e madhe se 100 MB. Shkarkimi i saj mund të hajë ca kohë!",
    "None" : "Asnjë",
    "Login" : "Hyrje",
    "Plain" : "E thjeshtë",
    "NT LAN Manager" : "Përgjegjës Rrjeti NT",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Shërbyes email-esh",
    "This is used for sending out notifications." : "Ky përdoret për të dërguar njoftime.",
    "Send mode" : "Mënyrë dërgimi",
    "Encryption" : "Fshehtëzim",
    "From address" : "Nga adresa",
    "mail" : "email",
    "Authentication method" : "Metodë mirëfilltësimi",
    "Authentication required" : "Lypset mirëfilltësim",
    "Server address" : "Adresë shërbyesi",
    "Port" : "Portë",
    "Credentials" : "Kredenciale",
    "SMTP Username" : "Emër përdoruesi SMTP",
    "SMTP Password" : "Fjalëkalim SMTP",
    "Store credentials" : "Depozitoji kredencialet",
    "Test email settings" : "Testoni rregullimet e email-it",
    "Send email" : "Dërgo email",
    "Security & setup warnings" : "Sinjalizime sigurie & rregullimi",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP-ja nuk duket të jetë rregulluar si duhet për të kërkuar ndryshore mjedisi sistemi. Testi me getenv(\"PATH\") kthen vetëm një përgjigje të zbrazët.",
    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Ju lutemi, kontrolloni <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentimin e instalimit ↗</a> për shënime rreth formësimit të php-së dhe formësimin php të shërbyesit tuaj, veçanërisht kur përdoret using php-fpm.",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Rregullimi Vetëm-Lexim u aktivizua. Kjo parandalon rregullimin e disa parametrave përmes ndërfaqes web. Më tej, për çdo përditësim kartela lyp të kalohet dorazi si e shkrueshme.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "Duket se PHP-ja është rregulluar që të heqë blloqe të brendshme dokumentimi. Kjo do t’i bëjë të papërdrshme disa aplikacione bazë.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Kjo ka gjasa të jetë shkaktuar nga një fshehtinë/përshpejtues i tillë si Zend OPcache ose eAccelerator.",
    "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Baza juaj e të dhënave nuk xhiron me nivelin \"READ COMMITED\" e izolimit për ndërveprimet. Kjo mund të shkaktojë probleme, kur kryhen paralelisht disa veprime njëherësh.",
    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "Ka të instaluar %1$s nën versionin %2$s, për arsye qëndrueshmërie dhe performance këshillojmë të përditësohet me një version %1$s më të ri.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Moduli PHP 'fileinfo' mungon. Ju këshillojmë me forcë ta aktivizoni këtë modul, për të patur përfundimet më të mira në zbulim llojesh MIME.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Kyçja e kartelave gjatë transaksioneve është e çaktivizuar, kjo mund të sjellë probleme me gjendje <em>race conditions</em>. Që të shmangni këto probleme, aktivizoni 'filelocking.enabled' te config.php. Për më tepër të dhëna, shihni <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentimin ↗</a>.",
    "Transactional file locking should be configured to use memory-based locking, not the default slow database-based locking. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Kyçja e kartelave gjatë transaksioneve duhet formësuar që të përdorë kyçje me bazë kujtesën, jo kyçjen parazgjedhje, të ngadaltë, të bazuar në bazë të dhënash. Për më tepër të dhëna, shihni <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentimin ↗</a>.",
    "System locale can not be set to a one which supports UTF-8." : "Si vendore sistemi nuk mund të caktohet një që mbulon UTF-8.",
    "This means that there might be problems with certain characters in file names." : "Kjo do të thotë që mund të ketë probleme me disa shenja në emra kartelash.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Këshillojmë me forcë instalimin në sistemin tuaj të paketave të domosdoshme për mbulim të një prej vendoreve vijuese: %s.",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Nëse instalimi juaj nuk është bërë në rrënjë të përkatësisë dhe përdor cron sistemi, mund të ketë probleme me prodhimin e URL-së. Që të shmangen këto probleme, ju lutemi, jepini mundësisë \"overwrite.cli.url\" te kartela juaj config.php vlerën e shtegut webroot të instalimit tuaj (E këshillueshme: \"%s\")",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "Si bazë të dhënash përdoret SQLite. Për instalime më të ngarkuara, këshillojmë të kalohet në një program tjetër baze të dhënash.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Përdorimi i SQLite-it nuk këshillohet veçanërisht kur përdoret klienti desktop për njëkohësim kartelash.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Për të kaluar te një tjetër bazë të dhënash përdorni mjetin rresht urdhrash: 'occ db:convert-type', ose shihni <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentimin ↗</a>.",
    "We recommend to enable system cron as any other cron method has possible performance and reliability implications." : "Këshillojmë të aktivizoni cron-in e sistemit, ngaqë çfarëdo metode cron tjetër ka, me gjasa, ndikime në funksionimin dhe qëndrueshmërinë e platformës.",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "S’qe e mundur të përmbushej akti cron përmes CLI-së. U shfaqën gabimet teknike vijuese:",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Ju lutemi, rihidhuni një sy <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">udhërrëfyesve të instalimit ↗</a>, dhe kontrolloni te <a href=\"#log-section\">regjistri</a> për çfarëdo gabimesh apo sinjalizimesh.",
    "All checks passed." : "I kaloi krejt kontrollet.",
    "System Status" : "Gjendje Sistemi",
    "Tips & tricks" : "Ndihmëza & rrengje",
    "How to do backups" : "Si të bëhen kopjeruajtje",
    "Advanced monitoring" : "Mbikëqyrje e mëtejshme",
    "Performance tuning" : "Përimtime performance",
    "Improving the config.php" : "Si të përmirësohet config.php",
    "Theming" : "Ndryshim teme grafike",
    "Hardening and security guidance" : "Udhëzime për forcim dhe siguri",
    "Get the apps to sync your files" : "Merrni aplikacionet për njëkohësim të kartelave tuaja",
    "Desktop client" : "Klient desktopi",
    "Android app" : "Aplikacion për Android",
    "iOS app" : "Aplikacion për iOS",
    "If you want to support the project\n\t\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\t\tor\n\t\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Nëse doni të përkrahni projektin,\n\t\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">merrni pjesë në zhvillim</a>\n\t\t\tose\n\t\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">përhapni fjalën</a>!",
    "Show First Run Wizard again" : "Shfaqe sërish Ndihmësin e Herës së Parë",
    "Profile picture" : "Foto profili",
    "Upload new" : "Ngarko të re",
    "Select from Files" : "Përzgjidhni prej Kartelash",
    "Remove image" : "Hiqe figurën",
    "png or jpg, max. 20 MB" : "png ose jpg, maks. 20 MB",
    "Picture provided by original account" : "Foto e prurë nga llogaria origjinale",
    "Cancel" : "Anuloje",
    "Choose as profile picture" : "Zgjidhni një foto profili",
    "Full name" : "Emër i plotë",
    "No display name set" : "S’është caktuar emër për në ekran",
    "Email" : "Email",
    "Your email address" : "Adresa juaj email",
    "Change email" : "Ndryshoje email-in",
    "Set email" : "Caktoje si email",
    "For password recovery and notifications" : "Për rimarrje fjalëkalimesh dhe njoftime ",
    "No email address set" : "S’është caktuar adresë email",
    "You are member of the following groups:" : "Jeni anëtar i grupeve vijuese:",
    "Password" : "Fjalëkalim",
    "Unable to change your password" : "S’arrihet të ndryshohet fjalëkalimi juaj",
    "Current password" : "Fjalëkalimi i tanishëm",
    "New password" : "Fjalëkalimi i ri",
    "Change password" : "Ndrysho fjalëkalimin",
    "Language" : "Gjuhë",
    "Help translate" : "Ndihmoni në përkthim",
    "Unlimited" : "E pakufizuar",
    "You are using %s of %s" : "Po përdorni %s nga %s",
    "You are using %s of %s (%s %%)" : "Po përdorni %s nga %s (%s %%)",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Krijuar nga {communityopen}bashkësia ownCloud{linkclose}, {githubopen}kodi burim{linkclose} mund të përdoret sipas licencës {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
    "Sessions" : "Sesione",
    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "Këta janë klientët web, desktop dhe celular të futur në këtë çast në ownCloud-in tuaj.",
    "Browser" : "Shfletues",
    "Most recent activity" : "Veprimtaria më e freskët",
    "App passwords" : "Fjalëkalim aplikacioni",
    "You've linked these apps." : "I keni lidhur këto aplikacione.",
    "Name" : "Emër",
    "An app password is a passcode that gives an app or device permissions to access your %s account." : "Fjalëkalimet e aplikacioneve janë kodkalime që u japin leje një aplikacioni ose pajisjeje të hyjnë në llogarinë tuaj %s.",
    "App name" : "Emër aplikacioni",
    "Create new app password" : "Krijoni fjalëkalim aplikacioni të ri",
    "Use the credentials below to configure your app or device." : "Përdorni kredencialet më poshtë për të formësuar aplikacionin apo pajisjen tuaj.",
    "Username" : "Emër përdoruesi",
    "Done" : "U bë",
    "Version" : "Version",
    "Personal" : "Personale",
    "Admin" : "Admin",
    "Error" : "Gabim",
    "No panels for this section." : "S’ka panele për këtë ndarje.",
    "Show enabled/disabled option" : "Shfaq mundësinë e aktivizuar/çaktivizuar",
    "Show storage location" : "Shfaq vendndodhje depozite",
    "Show last log in" : "Shfaq hyrjen e fundit",
    "Show user backend" : "Shfaq programin klient të përdoruesit",
    "Send email to new user" : "Dërgo email përdoruesi të ri",
    "Show email address" : "Shfaq adresë email",
    "E-Mail" : "Email",
    "Create" : "Krijoje",
    "Admin Recovery Password" : "Fjalëkalim Rikthimesh Nga Përgjegjësi",
    "Enter the recovery password in order to recover the users files during password change" : "Jepni fjalëkalim rimarrje që të mund të rimerrni kartela përdoruesi gjatë ndryshimit të fjalëkalimit",
    "Add Group" : "Shtoni Grup",
    "Group" : "Grup",
    "Everyone" : "Kushdo",
    "Admins" : "Administratorë",
    "Default Quota" : "Kuota Parazgjedhje",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Ju lutemi, jepni kuotë depozite (psh: \"512 MB\" ose \"12 GB\")",
    "Other" : "Tjetër",
    "Full Name" : "Emri i Plotë",
    "Group Admin for" : "Admin Grupi për",
    "Quota" : "Kuota",
    "Storage Location" : "Vendndodhje Depozite",
    "User Backend" : "Program klient i përdoruesit",
    "Last Login" : "Hyrja e fundit",
    "change full name" : "ndryshoni emrin e plotë",
    "set new password" : "caktoni fjalëkalim të ri",
    "change email address" : "ndryshoni adresën email",
    "Default" : "Parazgjedhje",
    "Change" : "Ndryshoje",
    "Share" : "Ndaje",
    "installing and updating apps via the market or Federated Cloud Sharing" : "instalim dhe përditësim aplikacionesh përmes tregut ose Federated Cloud Sharing",
    "White-listed Domains" : "Përkatësi të Lejuara",
    "Domain" : "Përkatësi",
    "Add Domain" : "Shtoni Përkatësi",
    "CORS" : "CORS",
    "User ID" : "ID përdoruesi",
    "Email address" : "Adresë email",
    "Invalid email address" : "Adresë email e pavlefshme",
    "Extra field to display in autocomplete results" : "Fushë ekstra për shfaqje në përfundime vetëplotësimesh",
    "Restrict users to only share with groups they are member of" : "Kufizoji përdoruesit të ndajnë vetëm me grupe anëtarë të të cilëve janë",
    "Default user and group share permissions" : "Leje parazgjedhje për ndarje nga përdorues dhe grupe",
    "Enforce password protection for read-only links" : "Zbato me detyrim mbrojtje përmes fjalëkalimi për lidhje të llojit vetëm-lexim",
    "Enforce password protection for read & write links" : "Zbato me detyrim mbrojtje përmes fjalëkalimi për lidhje të llojit lexim & shkrim",
    "Enforce password protection for upload-only (File Drop) links" : "Zbato me detyrim mbrojtje përmes fjalëkalimi për lidhje të llojit vetëm-ngarkim (File Drop)",
    "You are using %s" : "Po përdorni %s",
    "No Domains." : "S’ka Përkatësi.",
    "Are you sure you want to remove this domain?" : "Jeni i sigurt se doni të hiqet kjo përkatësi?",
    "Add" : "Shtoni",
    "Empty app name is not allowed." : "Nuk lejohet emër hapësire i zbrazët.",
    "The config file is read only. Please adjust your setup by editing the config file manually." : "Kartela e formësimit është vetëm e lexueshme. Ju lutemi, përpunojeni rregullimin tuaj duke e përpunuar dorazi e formësimit.",
    "Email changed successfully for {user}." : "Email-i për {user} u ndryshua me sukses.",
    "You are not a member of any groups." : "S’jeni anëtar i ndonjë grupi.",
    "In a clustered setup please make sure to sync the config.php file across all nodes." : "Në një sistem cluster sigurohuni të njëkohësoni kartelën config.php në krejt nyjet.",
    "These are the web, desktop and mobile clients currently logged in to your %s." : "Këta janë klientët web, desktop dhe celular të futur te %s juaj këtë çast.",
    "Automatically accept new incoming local user shares" : "Prano vetvetiu ndarje të reja që vijnë nga përdorues vendorë",
    "Legal" : "Ligjore",
    "Imprint URL:" : "URL Imprint-i:",
    "Imprint URL" : "URL Imprint-i",
    "Privacy Policy URL:" : "URL Rregullash Privatësie:",
    "Privacy Policy URL" : "URL Rregullash Privatësie",
    "App passwords / tokens" : "Fjalëkalime / token aplikacioni",
    "App passwords or tokens are passcodes that give an app or device permissions to access your %s account." : "Fjalëkalimet ose token-ët e aplikacionit janë frazëkalime që i japin leje një aplikacioni ose pajisjeje të hyjë në llogarinë tuaj %s.",
    "Use them as a security measure to hide your actual password which you may only want to use for web interface login." : "Përdorini ato si një masë sigurie për të fshehur fjalëkalimin tuaj faktik, të cilin mund të doni ta përdorni vetëm për hyrje në ndërfaqen web.",
    "Create new app passcode" : "Krijo fjalëkalim të ri aplikacioni",
    "Password / Token" : "Fjalëkalim / Token",
    "Owner language" : "Gjuha e të zotit",
    "Language used for public mail notifications for shared files" : "Gjuhë e përdorur për njoftime publike me email për kartela të ndara me të tjerët",
    "Wrong current password" : "Fjalëkalim i tanishëm i gabuar",
    "The new password cannot be the same as the previous one" : "Fjalëkalimi i ri s’mund të jetë i njëjtë me atë të mëparshmin"
},
"nplurals=2; plural=(n != 1);");
